Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1332)

Unified Diff: Source/modules/crypto/NormalizeAlgorithm.h

Issue 19885002: WebCrypto: Add interfaces for importKey(). (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: Rebase and rename Interface --> Private Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/modules/crypto/KeyOperation.cpp ('k') | Source/modules/crypto/NormalizeAlgorithm.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/modules/crypto/NormalizeAlgorithm.h
diff --git a/Source/modules/crypto/NormalizeAlgorithm.h b/Source/modules/crypto/NormalizeAlgorithm.h
index 93d30db2f60e551d9b3d1dd4ac7a4f9c66abd721..634d4aafd1da981fcccbea9488a3fe654d66e5bd 100644
--- a/Source/modules/crypto/NormalizeAlgorithm.h
+++ b/Source/modules/crypto/NormalizeAlgorithm.h
@@ -31,8 +31,6 @@
#ifndef NormalizeAlgorithm_h
#define NormalizeAlgorithm_h
-#include "wtf/Assertions.h"
-
namespace WebKit { class WebCryptoAlgorithm; }
namespace WebCore {
@@ -55,8 +53,9 @@ enum AlgorithmOperation {
};
// Normalizes an algorithm identifier (dictionary) into a WebCryptoAlgorithm. If
// normalization fails then returns false and sets |es|.
bool normalizeAlgorithm(const Dictionary&, AlgorithmOperation, WebKit::WebCryptoAlgorithm&, ExceptionState&) WARN_UNUSED_RETURN;
+bool normalizeAlgorithmForImportKey(const Dictionary&, WebKit::WebCryptoAlgorithm&, ExceptionState&) WARN_UNUSED_RETURN;
} // namespace WebCore
« no previous file with comments | « Source/modules/crypto/KeyOperation.cpp ('k') | Source/modules/crypto/NormalizeAlgorithm.cpp » ('j') | no next file with comments »
@@ -55,8 +53,9 @@ enum AlgorithmOperation {
};
// Normalizes an algorithm identifier (dictionary) into a WebCryptoAlgorithm. If
-// normalization fails then returns false and sets |es|.
+// normalization fails then returns false and sets the ExceptionState.
bool normalizeAlgorithm(const Dictionary&, AlgorithmOperation, WebKit::WebCryptoAlgorithm&, ExceptionState&) WARN_UNUSED_RETURN;

Powered by Google App Engine
This is Rietveld 408576698